@@ -25,8 +25,8 @@ M(Header,Serialize)(const HTLIB_Header* headers, USHORT header_len,
 BOOL
 M(Header,HasConnectionClose)(const HTLIB_Header* header_buffer, USHORT blen);
 
-void
-M(Header,SetDate)(char* buf32);
+const char*
+M(Header,GetHttpStatusMessage)(int status);
 
 #endif
   
